@@ -17,7 +17,7 @@ else:
         logger.warning("Running gevent.monkey.patch_all() since not run previously")
         gevent.monkey.patch_all()
 
-from ...compat.environ import *
+from ...compat import *
 from ...http import Request as BaseRequest
 from ...utils import ByteString
 from .. import Payload, BaseWebsocketServer
