@@ -1,143 +1,42 @@
 # -*- coding: utf-8 -*-
 from __future__ import unicode_literals, division, print_function, absolute_import
 import json
+import io
 
 from requests.auth import _basic_auth_str
 
-from endpoints.compat.environ import *
-from endpoints.compat.imports import parse as urlparse, BaseHTTPRequestHandler
-from endpoints.http import Headers, Url, Response, Request, Environ
+from endpoints.compat import *
+from endpoints.http import Headers, Url, Response, Request, Environ, Body
 from endpoints.utils import String, ByteString
 from . import testdata, TestCase, Server
 
 
-class EnvironTest(TestCase):
-    def test_values(self):
-        d = Environ()
+class BodyTest(TestCase):
+    def test_bad_content_type(self):
+        """make sure a form upload content type with json body fails correctly"""
+        r = Request()
+        r.environ["REQUEST_METHOD"] = "POST"
 
-        d["foo"] = None
-        self.assertEqual(None, d["foo"])
+        b = b"plain text body"
+        r.headers.update({'content-length': String(len(b))})
+        r.headers.pop("content-type", None)
+        body = Body(io.BytesIO(b), r)
+        self.assertEqual(b, body.file.read())
 
-        d["bar"] = 1
-        self.assertEqual(1, d["bar"])
+        b = b"foo=bar&che=baz&foo=che"
+        r.headers.update({'content-type': 'application/json', 'content-length': String(len(b))})
+        if is_py2:
+            with self.assertRaises(ValueError):
+                body = Body(io.BytesIO(b), r)
 
+        else:
+            with self.assertRaises(json.JSONDecodeError):
+                body = Body(io.BytesIO(b), r)
 
-class HeadersTest(TestCase):
-    def test_midbody_capital_letter(self):
-        """Previously, before June 2019, our headers didn't handle WebSocket correctly
-        instead lowercasing the S to Websocket"""
-        d = Headers()
-        d["Sec-WebSocket-Key"] = "foobar"
-        self.assertTrue("Sec-Websocket-Key" in d)
-        d2 = dict(d)
-        self.assertFalse("Sec-Websocket-Key" in d2)
-        self.assertTrue("Sec-WebSocket-Key" in d2)
-
-    def test_bytes(self):
-        d = Headers()
-        name = testdata.get_unicode()
-        val = ByteString(testdata.get_unicode())
-        d[name] = val
-        self.assertEqual(d[name], String(val))
-
-    def test_different_original_keys(self):
-        """when setting headers using 2 different original keys it wouldn't be uniqued"""
-        d = Headers()
-        d['Content-Type'] = "application/json"
-        d['content-type'] = "text/plain"
-        self.assertEqual(1, len(d))
-        self.assertEqual("text/plain", d["CONTENT-TYPE"])
-
-    def test_lifecycle(self):
-        d = Headers()
-        d["foo-bar"] = 1
-        self.assertEqual("1", d["Foo-Bar"])
-        self.assertEqual("1", d["fOO-bAr"])
-        self.assertEqual("1", d["fOO_bAr"])
-
-    def test_pop(self):
-        d = Headers()
-        d['FOO'] = 1
-        r = d.pop('foo')
-        self.assertEqual("1", r)
-
-        with self.assertRaises(KeyError):
-            d.pop('foo')
-
-        with self.assertRaises(KeyError):
-            d.pop('FOO')
-
-    def test_normalization(self):
-
-        keys = [
-            "Content-Type",
-            "content-type",
-            "content_type",
-            "CONTENT_TYPE"
-        ]
-
-        v = "foo"
-        d = {
-            "CONTENT_TYPE": v,
-            "CONTENT_LENGTH": 1234
-        }
-        headers = Headers(d)
-
-        for k in keys:
-            self.assertEqual(v, headers["Content-Type"])
-
-        headers = Headers()
-        headers["CONTENT_TYPE"] = v
-
-        for k in keys:
-            self.assertEqual(v, headers["Content-Type"])
-
-        #with self.assertRaises(KeyError):
-        #    headers["foo-bar"]
-
-        for k in keys:
-            self.assertTrue(k in headers)
-
-    def test_iteration(self):
-        hs = Headers()
-        hs['CONTENT_TYPE'] = "application/json"
-        hs['CONTENT-LENGTH'] = "1234"
-        hs['FOO-bAR'] = "che"
-        for k in hs.keys():
-            self.assertRegex(k, r"^[A-Z][a-z]+(?:\-[A-Z][a-z]+)*$")
-            self.assertTrue(k in hs)
-
-        for k, v in hs.items():
-            self.assertRegex(k, r"^[A-Z][a-z]+(?:\-[A-Z][a-z]+)*$")
-            self.assertEqual(hs[k], v)
-
-        for k in hs:
-            self.assertRegex(k, r"^[A-Z][a-z]+(?:\-[A-Z][a-z]+)*$")
-            self.assertTrue(k in hs)
-
-    def test___init__(self):
-        d = {"foo-bar": "1"}
-        hs = Headers(d)
-        self.assertEqual("1", hs["foo-bar"])
-        self.assertEqual(1, len(hs))
-
-        d = [("foo-bar", "1")]
-        hs = Headers(d)
-        self.assertEqual("1", hs["foo-bar"])
-        self.assertEqual(1, len(hs))
-
-        d = [("foo-bar", "1")]
-        hs = Headers(d, bar_foo="2")
-        self.assertEqual("1", hs["foo-bar"])
-        self.assertEqual("2", hs["bar-foo"])
-        self.assertEqual(2, len(hs))
-
-    def test_update(self):
-        h = Headers()
-        h["foo"] = "1"
-        self.assertEqual("1", h["foo"])
-        h.update({"foo": "2"})
-        self.assertEqual("2", h["foo"])
+        b = b'{"foo": ["bar", "che"], "che": "baz"}'
+        r.headers.update({'content-type': "application/x-www-form-urlencoded", 'content-length': String(len(b))})
+        with self.assertRaises(ValueError):
+            body = Body(io.BytesIO(b), r)
 
 
 class RequestTest(TestCase):
@@ -295,12 +194,12 @@ class RequestTest(TestCase):
 
         r = Request()
         r.query = query
-        self.assertEqual(urlparse.parse_qs(r.query, True), urlparse.parse_qs(query, True))
+        self.assertEqual(parse.parse_qs(r.query, True), parse.parse_qs(query, True))
         self.assertEqual(r.query_kwargs, query_kwargs)
 
         r = Request()
         r.query_kwargs = query_kwargs
-        self.assertEqual(urlparse.parse_qs(r.query, True), urlparse.parse_qs(query, True))
+        self.assertEqual(parse.parse_qs(r.query, True), parse.parse_qs(query, True))
         self.assertEqual(r.query_kwargs, query_kwargs)
 
     def test_get_header(self):
@@ -408,8 +307,7 @@ class ResponseTest(TestCase):
 
 class UrlTest(TestCase):
     def test_module(self):
-        controller_prefix = "url_module"
-        c = Server(controller_prefix, {
+        c = Server(contents={
             "foo": [
                 "from endpoints import Controller",
                 "class Bar(Controller):",
